@@ -45,11 +45,12 @@ class WindowsVolumeForm(NetBoxModelForm):
         help_text="The mapped drives to the volume e.g. Hard Drive 1",
     )
     size = IntegerField(
-        required=True,
+        required=False,
         label="Size (GB)",
         help_text="The size of the disk size mapping e.g. 25",
         validators=[MinValueValidator(1)],
     )
+    loaded_drive = Drive.objects.all()
 
     fieldsets = (
         (
