@@ -42,11 +42,13 @@ class Drive(NetBoxModel):
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:drive", kwargs={"pk": self.pk})
 
-    # this is not needed if small_image is created at set_image
     def save(self, *args, **kwargs):
-        number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created").count()
+        is_already_implemented = Drive.objects.filter(id=self.pk).count()
+        if is_already_implemented == 0:
+            number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created").count()
+
+            self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
 
-        self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
         super(Drive, self).save(*args, **kwargs)
 
     @property
@@ -105,6 +107,10 @@ class LinuxVolume(NetBoxModel):
             "description",
         ]
 
+    prerequisite_models = (
+        'dcim.platform'
+    )
+
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
 
@@ -148,6 +154,10 @@ class WindowsVolume(NetBoxModel):
             "description",
         ]
 
+    prerequisite_models = (
+        'dcim.platform'
+    )
+
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:windowsvolume", kwargs={"pk": self.pk})
 
