@@ -29,7 +29,7 @@ class RelatedDrives(PluginTemplateExtension):
 
         platform = obj.platform
         if platform is not None:
-            if platform.name.__contains__('Windows'):
+            if platform.name.lower().__contains__('windows'):
                 return self.render(
                     "netbox_storage/volume/windowsvolume_box.html",
                     extra_context={
@@ -38,7 +38,7 @@ class RelatedDrives(PluginTemplateExtension):
                         "type": type(obj.platform)
                     },
                 )
-            elif platform.name.__contains__('linux'):
+            elif platform.name.lower().__contains__('linux'):
                 return self.render(
                     "netbox_storage/volume/linuxvolume_box.html",
                     extra_context={
